Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3032)

Unified Diff: base/task_scheduler/scheduler_worker_pool.h

Issue 2068853002: Rename SchedulerThreadPool* to SchedulerWorkerPool* (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@rename1
Patch Set: CR Feedback fdoray@ Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: base/task_scheduler/scheduler_worker_pool.h
diff --git a/base/task_scheduler/scheduler_thread_pool.h b/base/task_scheduler/scheduler_worker_pool.h
similarity index 77%
rename from base/task_scheduler/scheduler_thread_pool.h
rename to base/task_scheduler/scheduler_worker_pool.h
index 774b11137652b9f2c4efe1359c3cb2b67ffab24f..96dc01c63d032e655bbac9967aaaaf68359d5bf2 100644
--- a/base/task_scheduler/scheduler_thread_pool.h
+++ b/base/task_scheduler/scheduler_worker_pool.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef BASE_TASK_SCHEDULER_SCHEDULER_THREAD_POOL_H_
-#define BASE_TASK_SCHEDULER_SCHEDULER_THREAD_POOL_H_
+#ifndef BASE_TASK_SCHEDULER_SCHEDULER_WORKER_POOL_H_
+#define BASE_TASK_SCHEDULER_SCHEDULER_WORKER_POOL_H_
#include <memory>
@@ -20,39 +20,39 @@ namespace internal {
class SchedulerWorkerThread;
class SequenceSortKey;
-// Interface for a thread pool.
-class BASE_EXPORT SchedulerThreadPool {
+// Interface for a worker pool.
+class BASE_EXPORT SchedulerWorkerPool {
public:
- virtual ~SchedulerThreadPool() = default;
+ virtual ~SchedulerWorkerPool() = default;
// Returns a TaskRunner whose PostTask invocations will result in scheduling
// Tasks with |traits| and |execution_mode| in this SchedulerThreadPool.
virtual scoped_refptr<TaskRunner> CreateTaskRunnerWithTraits(
const TaskTraits& traits,
ExecutionMode execution_mode) = 0;
// Inserts |sequence| with |sequence_sort_key| into a queue of Sequences that
// can be processed by any worker thread owned by this SchedulerThreadPool.
// Must only be used to put |sequence| back into a queue after running a Task
// from it. The thread that calls this doesn't have to belong to this
- // SchedulerThreadPool.
+ // SchedulerWorkerPool.
virtual void ReEnqueueSequence(scoped_refptr<Sequence> sequence,
const SequenceSortKey& sequence_sort_key) = 0;
// Posts |task| to be executed by this SchedulerThreadPool as part of
// |sequence|. If |worker_thread| is non-null, |task| will be scheduled to run
// on it specifically (note: |worker_thread| must be owned by this
// SchedulerThreadPool); otherwise, |task| will be added to the pending shared
// work. |task| won't be executed before its delayed run time, if any. Returns
// true if |task| is posted.
virtual bool PostTaskWithSequence(std::unique_ptr<Task> task,
scoped_refptr<Sequence> sequence,
SchedulerWorkerThread* worker_thread) = 0;
// Posts |task| to be executed by this SchedulerThreadPool as part of
// |sequence|. If |worker_thread| is non-null, |task| will be scheduled to run
// on it specifically (note: |worker_thread| must be owned by this
// SchedulerThreadPool); otherwise, |task| will be added to the pending shared
// work. This must only be called after |task| has gone through
// PostTaskWithSequence() and after |task|'s delayed run time.
virtual void PostTaskWithSequenceNow(
@@ -64,4 +64,4 @@ class BASE_EXPORT SchedulerThreadPool {
} // namespace internal
} // namespace base
-#endif // BASE_TASK_SCHEDULER_SCHEDULER_THREAD_POOL_H_
+#endif // BASE_TASK_SCHEDULER_SCHEDULER_WORKER_POOL_H_
« no previous file with comments | « base/task_scheduler/scheduler_thread_pool_impl_unittest.cc ('k') | base/task_scheduler/scheduler_worker_pool_impl.h » ('j') | no next file with comments »

Powered by Google App Engine
@@ -20,39 +20,39 @@ namespace internal {
// Returns a TaskRunner whose PostTask invocations will result in scheduling
- // Tasks with |traits| and |execution_mode| in this SchedulerThreadPool.
+ // Tasks with |traits| and |execution_mode| in this SchedulerWorkerPool.
virtual scoped_refptr<TaskRunner> CreateTaskRunnerWithTraits(
const TaskTraits& traits,
@@ -20,39 +20,39 @@ namespace internal {
ExecutionMode execution_mode) = 0;
// Inserts |sequence| with |sequence_sort_key| into a queue of Sequences that
- // can be processed by any worker thread owned by this SchedulerThreadPool.
+ // can be processed by any worker thread owned by this SchedulerWorkerPool.
// Must only be used to put |sequence| back into a queue after running a Task
// from it. The thread that calls this doesn't have to belong to this
@@ -20,39 +20,39 @@ namespace internal {
virtual void ReEnqueueSequence(scoped_refptr<Sequence> sequence,
const SequenceSortKey& sequence_sort_key) = 0;
- // Posts |task| to be executed by this SchedulerThreadPool as part of
+ // Posts |task| to be executed by this SchedulerWorkerPool as part of
// |sequence|. If |worker_thread| is non-null, |task| will be scheduled to run
// on it specifically (note: |worker_thread| must be owned by this
@@ -20,39 +20,39 @@ namespace internal {
// |sequence|. If |worker_thread| is non-null, |task| will be scheduled to run
// on it specifically (note: |worker_thread| must be owned by this
- // SchedulerThreadPool); otherwise, |task| will be added to the pending shared
+ // SchedulerWorkerPool); otherwise, |task| will be added to the pending shared
// work. |task| won't be executed before its delayed run time, if any. Returns
// true if |task| is posted.
@@ -20,39 +20,39 @@ namespace internal {
scoped_refptr<Sequence> sequence,
SchedulerWorkerThread* worker_thread) = 0;
- // Posts |task| to be executed by this SchedulerThreadPool as part of
+ // Posts |task| to be executed by this SchedulerWorkerPool as part of
// |sequence|. If |worker_thread| is non-null, |task| will be scheduled to run
// on it specifically (note: |worker_thread| must be owned by this
@@ -20,39 +20,39 @@ namespace internal {
// |sequence|. If |worker_thread| is non-null, |task| will be scheduled to run
// on it specifically (note: |worker_thread| must be owned by this
- // SchedulerThreadPool); otherwise, |task| will be added to the pending shared
+ // SchedulerWorkerPool); otherwise, |task| will be added to the pending shared
// work. This must only be called after |task| has gone through
// PostTaskWithSequence() and after |task|'s delayed run time.
This is Rietveld 408576698